<?php

/** MODULO CRIADO POR ODLANIER
 * @author Odlanier de Souza Mendes
 * @copyright Dlani prestashopbr.com
 * @email master_odlanier@hotmail.com
 * @version 1.1
 **/
 
include(dirname(__FILE__).'/classes/send_mail.php');
 
class NotInMail extends Module
{
	private $_html = '';
	private $_postErrors = array();
	private $_postSucess;
	
	private $_data;
	private $_mail_receiver;
	
	static private $_tpl_sms_files				= array(
		'name' => array(
			'new_client' 	=> 	'mail_new_client',
			'new_orders' 	=> 	'mail_new_order',
			'out_of_stock' 	=> 	'mail_out_of_stock'
			),
		'ext' => array(
			'new_client' 	=> 	'.txt',
			'new_orders' 	=> 	'.txt',
			'out_of_stock' 	=> 	'.txt'
			)
		);
	
	/**
	 * Contruindo o Modulo
	 */
	public function __construct()
	{
		$this->name 		= 'NotInMail';
		$this->displayName 	= 'Notifycation in Mail';
		$this->description = $this->l('Sends an Mail for each new order, new client and out of stock');
	
		$this->tab 			= 'Tools';
		$this->version 		= 1.1;
		$this->_data 		= array('shopname' => Configuration::get('PS_SHOP_NAME'));
		
		/* Get config vars */		 
		$this->_mail_receiver = Configuration::get('MAIL_RECEIVER');
	
		parent::__construct();
		
		/* The parent construct is required for translations */
		$this->page = basename(__FILE__, '.php');
		$this->displayName 	= 'Notify in Mail';
		$this->description = $this->l('Sends an Mail for each new order, new client and out of stock');
		$this->confirmUninstall = $this->l('Are you sure you want to delete your info?');
	}
   
   /**
    * Instalao do Modulo
    */
	public function	install()
	{
		if (!parent::install() OR
			!$this->registerHook('newOrder') 		OR
			!$this->registerHook('updateQuantity') 	OR
			!$this->registerHook('createAccount'))
			return false;
			
		Configuration::updateValue('MAIL_RECEIVER', 'legovsplaymobil@comandosemacao.com');

		return true;
	}
	
	/**
	 * Desinstalao do Modulo
	 */
	public function uninstall()
	{
		Configuration::deleteByName('MAIL_RECEIVER');		
		return parent::uninstall();
	}
	
	/**
	 * Obtendo dados do Template 
	 * 	da pasta Mails
	 */
	private function _getTplBody($tpl_file, $vars = array())
	{
		$iso = Language::getIsoById(intval(Configuration::get(PS_LANG_DEFAULT)));
		$file = dirname(__FILE__).'/mails/'.$iso.'/'.$tpl_file;
		if (!file_exists($file))
			die($file);
		$tpl = file($file);
		$template = str_replace(array_keys($vars), array_values($vars), $tpl);
		return (implode("\n", $template));
	}
	
	/**
	 * Funo que  executada em novos pedidos
	 */
	public function hookNewOrder($params)
	{
	
		$order 		= $params['order'];
		$customer 	= $params['customer'];
		$currency 	= $params['currency'];
		
		$templateVars =   array(
		'{firstname}' =>  $customer->firstname,
		'{lastname}' =>   $customer->lastname,
		'{order_name}' => sprintf("%06d", $order->id),
		'{shop_name}' =>  Configuration::get('PS_SHOP_NAME'),
		'{payment}' => 	  $order->payment,
		'{total_paid}' => $order->total_paid,
		'{currency}' =>   $currency->sign);

			
			$sms 				= new send_Mail();
			$number 			= $this->_new_order_numbers;
			$this->receiver 	= Configuration::get('MAIL_RECEIVER');
			$this->from			= Configuration::get('PS_SHOP_EMAIL');
			$this->msg 			= $this->_getTplBody(self::$_tpl_sms_files['name']['new_orders'].self::$_tpl_sms_files['ext']['new_orders'], $templateVars);
			$this->assunto 		= $this->l('New Order');
			$sms->_send_mail($this->receiver, $this->from, $this->msg, $this->assunto);
	}

	/**
	 * Funo que  executada na Atualizo dos produtos
	 */
	public function hookUpdateQuantity($params)
	{
	
		$product = $params['product'];
		$order 	 = $params['order'];
		
		$qty 	 = intval($params['product']['quantity_attribute'] ? $params['product']['quantity_attribute'] : $params['product']['stock_quantity']) - intval($params['product']['quantity']);
		if ($qty <= intval(Configuration::get('PS_LAST_QTIES')))
		{
			$templateVars = array(
			'{last_qty}' => intval(Configuration::get('PS_LAST_QTIES')),
			'{qty}' => $qty,
			'{product}' => strval($params['product']['name']));

			$this->msg = $this->_getTplBody(self::$_tpl_sms_files['name']['out_of_stock'].self::$_tpl_sms_files['ext']['out_of_stock'], $templateVars);
		}
		
		if (!empty($this->msg))
		{
			
			$sms 			= new send_Mail();
			$number 		= $this->_new_order_numbers;			
			$this->receiver = Configuration::get('MAIL_RECEIVER');
			$this->from		= Configuration::get('PS_SHOP_EMAIL');
			$this->assunto 	= $this->l('Out of Stock');	
			
			$sms->_send_mail($this->receiver, $this->from, $this->msg, $this->assunto);

		}
	}
	
	/**
	 * Funo que  gerada em um novo Cadastro 
	 * de um determinado cliente
	 */
		public function hookCreateAccount($params)
	{
		$customer 	= $params['newCustomer'];
			
		$templateVars =   array(
		'{shop_name}' 	=>  Configuration::get('PS_SHOP_NAME'),
		'{firstname}' 	=>  $customer->firstname,
		'{lastname}' 	=>  $customer->lastname,
		'{email}'		=> 	$customer->email
		);
		
		
			$sms 				= new send_Mail();
			$number 			= $this->_new_order_numbers;
			$this->receiver 	= Configuration::get('MAIL_RECEIVER');
			$this->from			= Configuration::get('PS_SHOP_EMAIL');
			$this->msg 			= $this->_getTplBody(self::$_tpl_sms_files['name']['new_client'].self::$_tpl_sms_files['ext']['new_client'], $templateVars);
			$this->assunto 		= $this->l('New Client');
			$sms->_send_mail($this->receiver, $this->from, $this->msg, $this->assunto);
	}

	/**
	 * Obtm dados do Form
	 */
	public function getContent()
	{
		$this->_html = '<h2>'.$this->displayName.'</h2>';

		if (!empty($_POST))
		{
				$this->_postValidation();
				if (!sizeof($this->_postErrors))
					$this->_postProcess();
				else
					foreach ($this->_postErrors AS $err)
						$this->_html .= $this->displayError($err);

		}
		
		$this->_displayForm();
		return $this->_html;
	}
	
	private function _displayForm()
	{
				if (!isset($_POST['btnSubmit']))
		{
			if ($this->_mail_receiver)
			{

				$_POST['mail_receiver'] 			= $this->_mail_receiver;

			}
		}
		
		$this->_html .= '<fieldset><legend><img src="'.$this->_path.'prefs.gif" alt="" title="" /> '.$this->l('Settings').'</legend>
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			
			<label>'.$this->l('Mail Recipient').'</label>
			<div class="margin-form"><input type="text" name="mail_receiver" size="30" value="'.(isset($_POST['mail_receiver']) ? $_POST['mail_receiver'] : '').'" style="margin-bottom:10px;" /><br />'.$this->l('ex: john@dohn.com').'</div>
			<br />
			<div class="margin-form"><input class="button" name="btnSubmit" value="'.$this->l('Update settings').'" type="submit" /></div>
		</form></fieldset>';
	}

	private function _postProcess()
	{
		Configuration::updateValue('MAIL_RECEIVER', $_POST['mail_receiver']);
		$this->_html .= $this->displayConfirmation($this->l('Settings updated'));
	}

	private function _postValidation()
	{

		if (empty($_POST['mail_receiver']) OR !Validate::isEmail($_POST['mail_receiver']) )
			$this->_postErrors[] = $this->l('Email Wrong !');

	}
	
	public function getStatsBody()
	{
		$currency = new Currency(Configuration::get('PS_CURRENCY_DEFAULT'));
		$currency->sign = $currency->iso_code;
		$query = '
		SELECT SUM(o.`total_paid_real`) as total_sales, COUNT(o.`total_paid_real`) as total_orders
		FROM `'._DB_PREFIX_.'orders` o
		WHERE (
			SELECT IF(os.`id_order_state` = 8, 0, 1)
			FROM `'._DB_PREFIX_.'orders` oo
			LEFT JOIN `'._DB_PREFIX_.'order_history` oh ON oh.`id_order` = oo.`id_order`
			LEFT JOIN `'._DB_PREFIX_.'order_state` os ON os.`id_order_state` = oh.`id_order_state`
			WHERE oo.`id_order` = o.`id_order`
			ORDER BY oh.`date_add` DESC, oh.`id_order_history` DESC
			LIMIT 1
		) = 1 ';
		$result = Db::getInstance()->getRow($query.'
		AND o.`date_add` >= DATE_SUB(\''.date('Y-m-d').' 20:00:00\', INTERVAL 1 DAY)
		AND o.`date_add` < \''.date('Y-m-d').' 20:00:00\'');
		$result2 = Db::getInstance()->getRow($query.'AND o.`date_add` LIKE \''.date('Y-m').'-%\'');
		
		return date('Y-m-d')."\n".
		$this->l('Orders:').' '.intval($result['total_orders'])."\n".
		$this->l('Sales:').' '.Tools::displayPrice($result['total_sales'], $currency, true)."\n".
		'('.$this->l('Month:').' '.Tools::displayPrice($result2['total_sales'], $currency, true).')';
	}
}

?>